@@ -1,6 +1,6 @@
 # Copyright (c) Naas Team.
 # Distributed under the terms of the GNU AGPL License.
-from .types import t_tz, t_size, error_busy, error_reject, copy_button
+from .types import t_tz, error_busy, error_reject, copy_button
 from IPython.core.display import display, Javascript, HTML
 from .runner.notifications import Notifications
 from .runner.callback import Callback
@@ -16,7 +16,7 @@ from .api import Api
 import requests
 import os
 
-__version__ = "1.3.16"
+__version__ = "1.5.1"
 __github_repo = "jupyter-naas/naas"
 __doc_url = "https://naas.gitbook.io/naas/"
 __canny_js = '<script>!function(w,d,i,s){function l(){if(!d.getElementById(i)){var f=d.getElementsByTagName(s)[0],e=d.createElement(s);e.type="text/javascript",e.async=!0,e.src="https://canny.io/sdk.js",f.parentNode.insertBefore(e,f)}}if("function"!=typeof w.Canny){var c=function(){c.q.push(arguments)};c.q=[],w.Canny=c,"complete"===d.readyState?l():w.attachEvent?w.attachEvent("onload",l):w.addEventListener("load",l,!1)}}(window,document,"canny-jssdk","script");</script>'  # noqa: E501
@@ -49,8 +49,15 @@ def get_last_version():
 
 
 def get_size():
-    response = requests.get(f"{n_env.api}/{t_size}")
-    return response.json()
+    webhook.manager.get_size()
+
+
+def reload_jobs():
+    webhook.manager.reload_jobs()
+
+
+def move_job(old_path, new_path):
+    webhook.manager.move_job(old_path, new_path)
 
 
 def changelog():
