@@ -6,6 +6,7 @@ from naas.types import (
     t_update,
     t_job,
     t_error,
+    t_health,
     t_start,
     t_notebook,
     t_asset,
@@ -13,8 +14,9 @@ from naas.types import (
     t_dependency,
     t_scheduler,
     t_list,
+    t_send,
 )
-from .env_var import n_env
+from .env_var import cpath, n_env
 import pandas as pd
 import datetime
 import errno
@@ -74,7 +76,7 @@ class Jobs:
                         "id": uid,
                         "type": "init_job_storage",
                         "filepath": self.__json_secrets_path,
-                        "status": "error",
+                        "status": t_error,
                         "error": str(e),
                     }
                 )
@@ -95,27 +97,47 @@ class Jobs:
             if len(self.__df) > 0:
                 self.__df = self.__df[self.__df.type.isin(filters)]
                 self.__dedup_jobs()
-                self.__migrate_oldPath()
         except Exception as err:
             print("Cannot cleanup", err)
 
-    def __migrate_oldPath(self):
-        cur_jobs = self.__df.to_dict("records")
-        for job in cur_jobs:
-            path = job["path"]
-            tmp_path = path.replace(n_env.path_naas_folder, "")
-            if not tmp_path.startswith(n_env.server_root) and os.path.exists(path):
-                new_path = os.path.join(
-                    n_env.path_naas_folder, n_env.server_root, tmp_path
-                )
-                os.makedirs(os.path.basename(new_path))
-                os.rename(path, new_path)
-                job["path"] = new_path
-            # previous path /home/ftp/.naas/toto/tata.py
-            # new path /home/ftp/.naas/home/ftp/toto/tata.py
-            # tmp_path = tmp_path.replace(n_env.path_naas_folder, '').replace(f"{n_env.server_root}/", '')
-        self.__df = pd.DataFrame(cur_jobs)
-        self.__df = self.__df.reset_index(drop=True)
+    async def move_job(self, uid, old_path, new_path):
+        async with self.__storage_sem:
+            try:
+                if len(self.__df) > 0:
+                    cur_elems = self.__df.query(f'path == "{old_path}"')
+                    new_elems = self.__df.query(f'path == "{new_path}"')
+                    if len(cur_elems.index) == 0:
+                        return {"status": t_skip, "error": "job not found"}
+                    elif len(new_elems.index) != 0:
+                        return {"status": t_skip, "error": "new job path exist"}
+                    index = cur_elems.index[0]
+                    self.__df.at[index, "path"] = new_path
+                    data = self.__df.to_dict("records")
+                    try:
+                        os.makedirs(os.path.dirname(new_path))
+                    except OSError:
+                        pass
+                    filename = os.path.basename(old_path)
+                    dirname = os.path.dirname(old_path)
+                    new_filename = os.path.basename(new_path)
+                    os.rename(old_path, new_path)
+                    moved = [{"from": cpath(old_path), "to": cpath(new_path)}]
+                    for ffile in os.listdir(dirname):
+                        if ffile.endswith(f"__{filename}"):
+                            tmp_path = os.path.join(dirname, ffile)
+                            start = ffile.replace(filename, "")
+                            new_tmp_path = new_path.replace(
+                                new_filename, f"{start}{new_filename}"
+                            )
+                            moved.append(
+                                {"from": cpath(tmp_path), "to": cpath(new_tmp_path)}
+                            )
+                            os.rename(tmp_path, new_tmp_path)
+                    self.__save_to_file(uid, data)
+                    return {"status": t_send, "data": moved}
+            except Exception as e:
+                print("move_job", e)
+                return {"status": t_error, "error": str(e)}
 
     def __dedup_jobs(self):
         new_df = self.__df[
@@ -164,7 +186,7 @@ class Jobs:
                 {
                     "id": str(uid),
                     "type": "__get_save_from_file",
-                    "status": "exception",
+                    "status": t_error,
                     "filepath": self.__json_secrets_path,
                     "error": str(err),
                 }
@@ -184,7 +206,7 @@ class Jobs:
                 {
                     "id": str(uid),
                     "type": "__save_to_file",
-                    "status": "exception",
+                    "status": t_error,
                     "filepath": self.__json_secrets_path,
                     "error": str(err),
                 }
@@ -237,45 +259,52 @@ class Jobs:
         return res
 
     def __match_clear(self, cur_filename, filename, clear_all):
-        if clear_all and cur_filename.endwith(filename):
-            return True
-        elif not clear_all and cur_filename == filename:
+        if (
+            clear_all
+            and cur_filename.endswith(f"__{filename}")
+            or cur_filename == filename
+        ):
             return True
         else:
             return False
 
     def clear_file(self, uid, path, histo, mode=None):
         # possible format
-        # histo_filename
-        # out_filename
-        # histo_out_filename
-        filename = os.path.basename(path)
-        clear_all = False
-        if mode:
-            filename = f"{mode}_{filename}"
-        if histo and histo == "all":
-            clear_all = True
-        elif histo:
-            filename = f"{histo}_{filename}"
-        removed = []
-        dirname = os.path.dirname(path)
-        if os.path.exists(path):
-            for ffile in os.listdir(dirname):
-                if self.__match_clear(ffile, filename, clear_all):
-                    tmp_path = os.path.join(dirname, ffile)
-                    removed.append(tmp_path)
-                    self.__logger.info(
-                        {
-                            "id": uid,
-                            "filename": filename,
-                            "histo": histo,
-                            "type": "clear_file",
-                            "status": t_delete,
-                            "filepath": path,
-                        }
-                    )
-                    os.remove(tmp_path)
-        return removed
+        # histo___filename
+        # output__filename
+        # histo___output__filename
+        try:
+            filename = os.path.basename(path)
+            clear_all = False
+            if mode:
+                filename = f"{mode}__{filename}"
+            if histo and histo == "all":
+                clear_all = True
+            elif histo:
+                filename = f"{histo}___{filename}"
+            removed = []
+            dirname = os.path.dirname(path)
+            if os.path.exists(path):
+                for ffile in os.listdir(dirname):
+                    if self.__match_clear(ffile, filename, clear_all):
+                        tmp_path = os.path.join(dirname, ffile)
+                        os.remove(tmp_path)
+                        tmp_path = cpath(tmp_path)
+                        removed.append(tmp_path)
+                        self.__logger.info(
+                            {
+                                "id": uid,
+                                "filename": filename,
+                                "histo": histo,
+                                "type": "clear_file",
+                                "status": t_delete,
+                                "filepath": path,
+                            }
+                        )
+            return {"id": uid, "status": t_health, "data": removed}
+        except Exception as e:
+            print("clear_file", e)
+            return {"id": uid, "status": t_error, "error": str(e)}
 
     def list_files(self, uid, path, filetype, output=False):
         d = []
@@ -294,14 +323,12 @@ class Jobs:
                 split_list = ffile.split("___")
                 histo = split_list[0]
                 tmp_path = os.path.join(dirname, ffile)
-                tmp_path = tmp_path.replace(n_env.path_naas_folder, "").replace(
-                    f"{n_env.server_root}/", ""
-                )
+                tmp_path = cpath(tmp_path)
                 d.append({"timestamp": histo, "filepath": tmp_path})
         self.__logger.info(
             {
                 "id": uid,
-                "type": "clear_file",
+                "type": "list_files",
                 "filename": filename,
                 "status": t_list,
                 "filepath": path,
@@ -319,11 +346,7 @@ class Jobs:
                     data = self.__df.to_dict("records")
                     for d in data:
                         try:
-                            d["path"] = (
-                                d["path"]
-                                .replace(n_env.path_naas_folder, "")
-                                .replace(f"{n_env.server_root}/", "")
-                            )
+                            d["path"] = cpath(d["path"])
                             d["runs"] = json.loads(d.get("runs", "[]"))
                         except Exception:
                             d["runs"] = []
@@ -442,9 +465,7 @@ class Jobs:
             )
             self.__df.at[index, "runs"] = json.dumps(runs)
             self.__df.at[index, "lastRun"] = run_time
-            return t_update
-        else:
-            return t_skip
+        return t_update
 
     async def update(self, uid, path, target_type, value, params, status, run_time=0):
         data = None
@@ -473,7 +494,7 @@ class Jobs:
                 if res == t_error:
                     raise ServerError(
                         {
-                            "status": "error",
+                            "status": t_error,
                             "id": uid,
                             "data": [],
                             "error": "unknow error",
@@ -496,6 +517,6 @@ class Jobs:
                     }
                 )
                 raise ServerError(
-                    {"status": "error", "id": uid, "data": [], "error": str(e)},
+                    {"status": t_error, "id": uid, "data": [], "error": str(e)},
                     status_code=500,
                 )
